PALM-meteo: palmmeteo_stdplugins.wrf_utils.WrfPhysics Class Reference

PALM-meteo

Static Public Attributes | List of all members
palmmeteo_stdplugins.wrf_utils.WrfPhysics Class Reference
Inheritance diagram for palmmeteo_stdplugins.wrf_utils.WrfPhysics:
[legend]
Collaboration diagram for palmmeteo_stdplugins.wrf_utils.WrfPhysics:
[legend]

## Static Public Attributes
float | radius = 6370000.0
| Constants directly equivalent to WRF code. More...
int | base_temp = 300.
int | rd_d_cp = 2./7.
Static Public Attributes inherited from palmmeteo.library.PalmPhysics
float | g = 9.81
int | c_p = 1005.
int | r_d = 287.
int | p0 = 1e5
float | sigma_sb = 5.67037e-08
int | d_p0 = 1e-5
float | g_d_cp = g / c_p
int | cp_d_rd = c_p / r_d
int | rd_d_cp = r_d / c_p
int | radius = 6371.
float | R = 8.314

## Additional Inherited Members
Public Member Functions inherited from palmmeteo.library.PalmPhysics
def | barom_lapse0_pres (cls, p0, gp, gp0, t0)
def | barom_lapse0_gp (cls, gp0, p, p0, t0)
def | barom_ptn_pres (cls, p0, z, t0)
def | exner (cls, p)
def | exner_inv (cls, p)

## Member Data Documentation

## ◆ base_temp

int palmmeteo_stdplugins.wrf_utils.WrfPhysics.base_temp = 300.
| static

## ◆ radius

float palmmeteo_stdplugins.wrf_utils.WrfPhysics.radius = 6370000.0
| static

Constants directly equivalent to WRF code.

## ◆ rd_d_cp

int palmmeteo_stdplugins.wrf_utils.WrfPhysics.rd_d_cp = 2./7.
| static

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/wrf_utils.py